@@ -1,7 +1,7 @@
 package Perinci::Sub::CoerceArgs;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -237,8 +237,15 @@ sub _coerce_to_secs {
                 $min*60 + $s;
             return [200];
         }
-    } elsif (eval { require Time::Duration::Parse; $d = Time::Duration::Parse::parse_duration($val) } && !$@) {
-        $args->{$arg_name} = $d;
+    } elsif (eval { require Time::Duration::Parse::AsHash; $d = Time::Duration::Parse::AsHash::parse_duration($val) } && !$@) {
+        $args->{$arg_name} =
+            ($d->{years}   // 0) * 365*86400 +
+            ($d->{months}  // 0) *  30*86400 +
+            ($d->{weeks}   // 0) *   7*86400 +
+            ($d->{days}    // 0) *     86400 +
+            ($d->{hours}   // 0) *      3600 +
+            ($d->{minutes} // 0) *        60 +
+            ($d->{seconds} // 0);
         return [200];
     }
 
@@ -366,7 +373,7 @@ Perinci::Sub::CoerceArgs - Coerce arguments
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-25.
+This document describes version 0.10 of Perinci::Sub::CoerceArgs (from Perl distribution Perinci-Sub-CoerceArgs), released on 2015-09-26.
 
 =head1 SYNOPSIS
 
